@@ -226,6 +226,23 @@ def process_app_id(app_id, applications, client, spark_stage_analyzer, s3_upload
     application_end_time_ms = attempt.get('endTimeEpoch')
     logging.debug(f"Application {app_id} start time: {application_start_time_ms}, end time: {application_end_time_ms}")
     
+    if len(application.get('attempts', [])) > 1:
+        latest_attempt_id = client._get_latest_attempt_id(app_id)
+        if latest_attempt_id:
+            if args and args.debug:
+                print(f"📊 Application has {len(application['attempts'])} attempts - using latest attempt ID: {latest_attempt_id}")
+            logging.info(f"Application {app_id} has {len(application['attempts'])} attempts, using latest: {latest_attempt_id}")
+        else:
+            if args and args.debug:
+                print(f"📊 Application has {len(application['attempts'])} attempts - using base application ID")
+            logging.info(f"Application {app_id} has {len(application['attempts'])} attempts, using base app ID")
+    elif len(application.get('attempts', [])) == 1:
+        attempt_id = str(application['attempts'][0].get('attemptId', 0))
+        if attempt_id != "0":
+            if args and args.debug:
+                print(f"📊 Application has attempt ID: {attempt_id}")
+            logging.info(f"Application {app_id} has single attempt with ID: {attempt_id}")
+    
     try:
         print("🔄 Fetching stages...")
         stages = client.get_stages(app_id)
@@ -551,9 +568,28 @@ def run_analysis():
                     logging.debug(f"Fetched {len(applications) if applications else 0} applications for Databricks")
                     
                     if applications and len(applications) > 0:
-                        app_ids = [applications[0]['id']]
-                        print(f"✅ Found application: {applications[0]['id']}")
-                        logging.info(f"Using application ID: {applications[0]['id']}")
+                        app_id = applications[0]['id']
+                        app_ids = [app_id]
+                        print(f"✅ Found application: {app_id}")
+                        
+                        # Check if this application has multiple attempts
+                        if len(applications[0].get('attempts', [])) > 1:
+                            latest_attempt_id = client._get_latest_attempt_id(app_id)
+                            if latest_attempt_id:
+                                if args and args.debug:
+                                    print(f"📊 Application has {len(applications[0]['attempts'])} attempts - using latest attempt ID: {latest_attempt_id}")
+                            else:
+                                if args and args.debug:
+                                    print(f"📊 Application has {len(applications[0]['attempts'])} attempts - using base application ID")
+                        elif len(applications[0].get('attempts', [])) == 1:
+                            # Check if single attempt has non-zero attempt ID
+                            attempt_id = str(applications[0]['attempts'][0].get('attemptId', 0))
+                            if attempt_id != "0":
+                                if args and args.debug:
+                                    print(f"📊 Application has attempt ID: {attempt_id}")
+                                logging.info(f"Application {app_id} has single attempt with ID: {attempt_id}")
+                        
+                        logging.info(f"Using application ID: {app_id}")
                     else:
                         print_error_box(
                             "DATABRICKS APPLICATION NOT FOUND",
@@ -640,12 +676,41 @@ def run_analysis():
                         
                         app_table = []
                         for app in applications:
-                            app_table.append([app.get('id', 'N/A'), app.get('name', 'N/A')])
+                            app_id = app.get('id', 'N/A')
+                            app_name = app.get('name', 'N/A')
+                            attempts_count = len(app.get('attempts', []))
+                            
+                            # Add attempt information to the display (debug mode only)
+                            if args and args.debug:
+                                if attempts_count > 1:
+                                    latest_attempt_id = client._get_latest_attempt_id(app_id)
+                                    if latest_attempt_id:
+                                        app_display = f"{app_id} (latest attempt: {latest_attempt_id})"
+                                    else:
+                                        app_display = f"{app_id} ({attempts_count} attempts)"
+                                elif attempts_count == 1:
+                                    # Check if single attempt has non-zero attempt ID
+                                    attempt_id = str(app['attempts'][0].get('attemptId', 0))
+                                    if attempt_id != "0":
+                                        app_display = f"{app_id} (attempt: {attempt_id})"
+                                    else:
+                                        app_display = app_id
+                                else:
+                                    app_display = app_id
+                            else:
+                                app_display = app_id
+                            
+                            app_table.append([app_display, app_name])
                         
                         headers = ["Application ID", "Application Name"]
                         print("\nAvailable Applications:")
                         print(tabulate.tabulate(app_table, headers=headers, tablefmt="grid"))
                         
+                        # Show a note about multiple attempts if any exist
+                        multi_attempt_apps = [app for app in applications if len(app.get('attempts', [])) > 1]
+                        if multi_attempt_apps and args and args.debug:
+                            print("\n💡 Note: Applications with multiple attempts will automatically use the latest attempt.")
+                        
                         while True:
                             app_to_analyze = get_user_input("\n🔍 Enter the application id(s) to analyze, separated by commas without spaces (required): ")
                             if not app_to_analyze:
@@ -659,13 +724,25 @@ def run_analysis():
                                 print("Please enter at least one application ID from the list above.")
                                 continue
                             
-                            invalid_ids = [aid for aid in entered_app_ids if aid not in valid_app_ids]
+                            # Handle cases where user might have entered the full display string
+                            clean_app_ids = []
+                            for aid in entered_app_ids:
+                                # Extract just the app ID part if user entered the full display string
+                                if " (latest attempt:" in aid:
+                                    clean_aid = aid.split(" (latest attempt:")[0]
+                                elif " (" in aid and " attempts)" in aid:
+                                    clean_aid = aid.split(" (")[0]
+                                else:
+                                    clean_aid = aid
+                                clean_app_ids.append(clean_aid)
+                            
+                            invalid_ids = [aid for aid in clean_app_ids if aid not in valid_app_ids]
                             if invalid_ids:
                                 print(f"\n❌ Invalid application ID(s): {', '.join(invalid_ids)}")
                                 print("Please enter only valid application IDs from the list above.")
                                 continue
                             
-                            app_ids = entered_app_ids
+                            app_ids = clean_app_ids
                             break
 
                 except requests.exceptions.ConnectionError as e:
