@@ -1,6 +1,7 @@
 #!/usr/bin/env python3
 import os
 import sys
+import logging
 import typer
 from rich.console import Console
 from rich.prompt import Prompt, Confirm
@@ -18,6 +19,21 @@ from urllib.parse import urlparse, urljoin
 app = typer.Typer(help="Spark Analyzer Configuration Tool")
 console = Console()
 
+def setup_logging(debug=False):
+    """Setup logging configuration."""
+    if debug:
+        level = logging.DEBUG
+    else:
+        level = logging.INFO
+    
+    logging.basicConfig(
+        level=level,
+        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+        handlers=[
+            logging.StreamHandler(sys.stdout)
+        ]
+    )
+
 def print_error_box(title: str, message: str, help_text: str):
     """Print a formatted error box using rich."""
     console.print(Panel(
@@ -145,20 +161,52 @@ def extract_databricks_driver_id(url: str) -> Optional[str]:
     return None
 
 @app.callback(invoke_without_command=True)
-def callback(ctx: typer.Context):
-    """Spark Analyzer Configuration Tool."""
-    if ctx.invoked_subcommand is None:
-        # If no subcommand was specified, run configure
-        ctx.invoke(configure)
-
-@app.command()
-def configure(
+def callback(
+    ctx: typer.Context,
     config_dir: Optional[str] = typer.Option(
         None,
         "--config-dir",
         "-c",
         help="Directory to store configuration files"
+    ),
+    opt_out: Optional[str] = typer.Option(
+        None,
+        "--opt-out",
+        help="Comma-separated list of fields to opt out of (name,description,details)"
+    ),
+    save_local: bool = typer.Option(
+        False,
+        "--save-local",
+        help="Save analysis data locally instead of uploading to Onehouse"
+    ),
+    debug: bool = typer.Option(
+        False,
+        "--debug",
+        "-d",
+        help="Enable debug logging (DEBUG level, includes all requests/responses)"
+    ),
+    live_app: bool = typer.Option(
+        False,
+        "--live-app",
+        help="Indicate this is a live/running application (enables reverse processing and stage validation to handle race conditions)"
     )
+):
+    # Setup logging based on debug flag
+    setup_logging(debug)
+    if debug:
+        logging.debug("Debug logging enabled")
+    """Spark Analyzer Configuration Tool."""
+    if ctx.invoked_subcommand is None:
+        # If no subcommand was specified, run configure with the provided arguments
+        ctx.invoke(configure, config_dir=config_dir, opt_out=opt_out, save_local=save_local, debug=debug, live_app=live_app)
+
+@app.command()
+def configure(
+    config_dir: Optional[str] = None,
+    opt_out: Optional[str] = None,
+    save_local: bool = False,
+    debug: bool = False,
+    live_app: bool = False
 ):
     """Interactive configuration for Spark Analyzer."""
     if isinstance(config_dir, OptionInfo):
@@ -321,6 +369,7 @@ def configure(
     config = configparser.ConfigParser()
     config["server"] = {"base_url": history_server_url}
     config["cost_estimator"] = {"user_id": cost_estimator_id}
+    config["processing"] = {"live_app": str(live_app).lower()}
     
     with open(config_file, "w") as f:
         config.write(f)
@@ -422,30 +471,41 @@ def configure(
     if Confirm.ask("\nWould you like to run the analyzer now?"):
         console.print("\n[blue]Running Spark Analyzer...[/blue]")
         
-        save_local_mode = os.environ.get('SPARK_ANALYZER_SAVE_LOCAL_MODE') == '1'
-        save_local_flag = "--save-local " if save_local_mode else ""
-        
         original_args = os.environ.get('SPARK_ANALYZER_ORIGINAL_ARGS', '')
         original_args_str = f"{original_args} " if original_args else ""
         
+        # Add opt-out flag if provided
+        if opt_out:
+            original_args_str = f"--opt-out {opt_out} {original_args_str}"
+        
+        if debug:
+            original_args_str = f"--debug {original_args_str}"
+        
+        env = os.environ.copy()
+        env['SPARK_ANALYZER_FROM_CONFIG'] = '1'
+        
+        # Set save-local mode via environment variable instead of command line flag
+        if save_local:
+            env['SPARK_ANALYZER_SAVE_LOCAL_MODE'] = '1'
+        
         if connection_mode == "1":
             if history_server_url != "http://localhost:18080/api/v1":
                 # Custom URL
                 if cost_estimator_id:
-                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--server-url '{history_server_url}' --cost-estimator-id '{cost_estimator_id}'")
+                    subprocess.run(f"spark-analyzer {original_args_str}--server-url '{history_server_url}' --cost-estimator-id '{cost_estimator_id}'", shell=True, env=env)
                 else:
-                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--server-url '{history_server_url}'")
+                    subprocess.run(f"spark-analyzer {original_args_str}--server-url '{history_server_url}'", shell=True, env=env)
             else:
                 # Default URL
                 if cost_estimator_id:
-                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--local --cost-estimator-id '{cost_estimator_id}'")
+                    subprocess.run(f"spark-analyzer {original_args_str}--local --cost-estimator-id '{cost_estimator_id}'", shell=True, env=env)
                 else:
-                    os.system(f"spark-analyzer {save_local_flag}{original_args_str}--local")
+                    subprocess.run(f"spark-analyzer {original_args_str}--local", shell=True, env=env)
         elif connection_mode == "2":
             if cost_estimator_id:
-                os.system(f"spark-analyzer {save_local_flag}{original_args_str}--browser --cost-estimator-id '{cost_estimator_id}'")
+                subprocess.run(f"spark-analyzer {original_args_str}--browser --cost-estimator-id '{cost_estimator_id}'", shell=True, env=env)
             else:
-                os.system(f"spark-analyzer {save_local_flag}{original_args_str}--browser")
+                subprocess.run(f"spark-analyzer {original_args_str}--browser", shell=True, env=env)
 
 @app.command()
 def show():
