@@ -1,5 +1,5 @@
 import requests
-from typing import Dict, Any, Optional, Union, Callable
+from typing import Dict, Any, Optional, Union, Callable, Tuple
 import json
 import configparser
 import os
@@ -98,25 +98,18 @@ class APIClient:
             logging.debug(f"Using server URL from command line: {self.base_url}")
         elif env_var_url:
             self.base_url = env_var_url
-            logging.debug(f"Using server URL from environment variable: {self.base_url}")
-            logging.debug(f"All environment variables: {dict([(k,v) for k,v in os.environ.items() if 'SPARK_ANALYZER' in k])}")
+            logging.debug(f"Using server URL from environment: {self.base_url}")
         elif 'server' in self.config and 'base_url' in self.config['server']:
-            config_url = self.config.get('server', 'base_url').strip()
-            if config_url and config_url != "http://server-url:18080/api/v1":
-                self.base_url = config_url
-                logging.debug(f"Using custom URL from config: {self.base_url}")
-            else:
-                self.base_url = "http://localhost:18080"
-                logging.debug(f"Using default local mode URL: {self.base_url}")
+            self.base_url = self.config['server']['base_url']
+            logging.debug(f"Using server URL from config: {self.base_url}")
         else:
-            self.base_url = "http://localhost:18080"
-            logging.debug(f"No URL found in any source, using default: {self.base_url}")
+            self.base_url = base_url
+            logging.debug(f"Using default server URL: {self.base_url}")
         
-        if self.base_url.endswith('/'):
-            self.base_url = self.base_url[:-1]
-            
         self.original_url = self.base_url
         
+        self._app_attempt_cache = {}
+        
         logging.info(f"Using Spark History Server URL: {self.base_url}")
         
         if self.base_url.count('/') > 3 and not '/api/v1' in self.base_url:
@@ -236,10 +229,15 @@ class APIClient:
         
         self.workflow_type_keywords = {}
         try:
-            # Try to load workflow type keywords
-            keyword_paths = [
-                os.path.join("resources", "workflow_type_keywords.json"),
-            ]
+            # Try to load workflow type keywords using the same path resolution as SparkStageAnalyzer
+            keyword_paths = []
+            
+            # Get the directory of the current file (api_client.py)
+            current_dir = os.path.dirname(os.path.abspath(__file__))
+            # Construct path to the resources directory
+            resources_dir = os.path.join(os.path.dirname(current_dir), 'resources')
+            keywords_file = os.path.join(resources_dir, 'workflow_type_keywords.json')
+            keyword_paths.append(keywords_file)
             
             # Add package resource path using modern or legacy approach
             if MODERN_RESOURCES:
@@ -261,6 +259,7 @@ class APIClient:
                         with open(path, "r") as f:
                             self.workflow_type_keywords = json.load(f)
                         keywords_found = True
+                        logging.debug(f"Successfully loaded workflow keywords from: {path}")
                         break
                     except Exception as e:
                         logging.error(f"Error reading keywords file {path}: {str(e)}")
@@ -534,12 +533,78 @@ class APIClient:
             logging.error(f"Failed to get applications: {str(e)}")
             raise
 
+    def _get_application_attempts(self, app_id: str) -> Optional[Dict[str, Any]]:
+        logging.debug(f"Fetching attempts for application {app_id}")
+        try:
+            clean_app_id = app_id.strip()
+            attempts = self._make_request(f"/applications/{clean_app_id}")
+            logging.debug(f"Found {len(attempts.get('attempts', []))} attempts for application {app_id}")
+            return attempts
+        except Exception as e:
+            logging.debug(f"Failed to get attempts for {app_id}: {str(e)}")
+            return None
+
+    def _get_latest_attempt_id(self, app_id: str) -> Optional[str]:
+        if app_id in self._app_attempt_cache:
+            return self._app_attempt_cache[app_id]
+        
+        try:
+            attempts_data = self._get_application_attempts(app_id)
+            if not attempts_data or 'attempts' not in attempts_data:
+                self._app_attempt_cache[app_id] = None
+                return None
+            
+            attempts = attempts_data['attempts']
+            if not attempts:
+                self._app_attempt_cache[app_id] = None
+                return None
+            
+            if len(attempts) == 1:
+                attempt_id = str(attempts[0].get('attemptId', 0))
+                if attempt_id == "0":
+                    self._app_attempt_cache[app_id] = None
+                    return None
+                else:
+                    logging.debug(f"Single attempt with ID {attempt_id} for {app_id}")
+                    self._app_attempt_cache[app_id] = attempt_id
+                    return attempt_id
+            
+            latest_attempt = max(attempts, key=lambda x: x.get('attemptId', 0))
+            latest_attempt_id = str(latest_attempt.get('attemptId', 0))
+            
+            logging.debug(f"Latest attempt ID for {app_id}: {latest_attempt_id}")
+            self._app_attempt_cache[app_id] = latest_attempt_id
+            return latest_attempt_id
+        except Exception as e:
+            logging.warning(f"Error getting latest attempt ID for {app_id}: {str(e)}")
+            self._app_attempt_cache[app_id] = None
+            return None
+
+    def _build_app_endpoint(self, app_id: str, endpoint: str) -> str:
+        """Build API endpoint with attempt ID if needed."""
+        clean_app_id = app_id.strip()
+        
+        attempt_id = self._get_latest_attempt_id(clean_app_id)
+        
+        if attempt_id:
+            endpoint_path = f"/applications/{clean_app_id}/{attempt_id}{endpoint}"
+            logging.debug(f"Using attempt ID {attempt_id} for {clean_app_id}: {endpoint_path}")
+            return endpoint_path
+        else:
+            endpoint_path = f"/applications/{clean_app_id}{endpoint}"
+            logging.debug(f"No attempt ID needed for {clean_app_id}: {endpoint_path}")
+            return endpoint_path
+
+    def clear_attempt_cache(self):
+        self._app_attempt_cache.clear()
+        logging.debug("Cleared application attempt cache")
+    
     def get_executor_metrics(self, app_id: str) -> Dict[str, Any]:
         """Get executor metrics for a specific application."""
         logging.debug(f"Fetching executor metrics for application {app_id}")
         try:
-            clean_app_id = app_id.strip()
-            metrics = self._make_request(f"/applications/{clean_app_id}/executors")
+            endpoint = self._build_app_endpoint(app_id, "/executors")
+            metrics = self._make_request(endpoint)
             logging.debug(f"Found {len(metrics)} executor metrics entries")
             return metrics
         except Exception as e:
@@ -550,8 +615,8 @@ class APIClient:
         """Get all executor metrics for all applications."""
         logging.debug(f"Fetching all executor metrics for application {app_id}")
         try:
-            clean_app_id = app_id.strip()
-            metrics = self._make_request(f"/applications/{clean_app_id}/allexecutors")
+            endpoint = self._build_app_endpoint(app_id, "/allexecutors")
+            metrics = self._make_request(endpoint)
             logging.debug(f"Found {len(metrics)} total executor metrics entries")
             return metrics
         except Exception as e:
@@ -562,8 +627,8 @@ class APIClient:
         """Get the environment for a specific application."""
         logging.debug(f"Fetching environment for application {app_id}")
         try:
-            clean_app_id = app_id.strip()
-            env = self._make_request(f"/applications/{clean_app_id}/environment")
+            endpoint = self._build_app_endpoint(app_id, "/environment")
+            env = self._make_request(endpoint)
             logging.debug(f"Successfully retrieved environment for {app_id}")
             return env
         except Exception as e:
@@ -574,9 +639,9 @@ class APIClient:
         """Get details for a specific stage."""
         logging.debug(f"Fetching details for stage {stage_id} in application {app_id}")
         try:
-            clean_app_id = app_id.strip()
             clean_stage_id = str(stage_id).strip()
-            details = self._make_request(f"/applications/{clean_app_id}/stages/{clean_stage_id}?details=false")
+            endpoint = self._build_app_endpoint(app_id, f"/stages/{clean_stage_id}?details=false")
+            details = self._make_request(endpoint)
             logging.debug(f"Successfully retrieved details for stage {stage_id}")
             return details
         except Exception as e:
@@ -586,11 +651,11 @@ class APIClient:
     def check_stage_exists(self, app_id: str, stage_id: str) -> bool:
         logging.debug(f"Checking if stage {stage_id} exists in application {app_id}")
         try:
-            clean_app_id = app_id.strip()
             clean_stage_id = str(stage_id).strip()
+            endpoint = self._build_app_endpoint(app_id, f"/stages/{clean_stage_id}?details=false")
             
             api_base_url = self._ensure_api_path(self.base_url)
-            url = f"{api_base_url}/applications/{clean_app_id}/stages/{clean_stage_id}?details=false"
+            url = f"{api_base_url}{endpoint}"
             
             logging.debug(f"Making validation request to: {url}")
             
@@ -629,9 +694,9 @@ class APIClient:
         """Get details for a specific stage with tasks."""
         logging.debug(f"Fetching details with tasks for stage {stage_id} in application {app_id}")
         try:
-            clean_app_id = app_id.strip()
             clean_stage_id = str(stage_id).strip()
-            details = self._make_request(f"/applications/{clean_app_id}/stages/{clean_stage_id}?details=true")
+            endpoint = self._build_app_endpoint(app_id, f"/stages/{clean_stage_id}?details=true")
+            details = self._make_request(endpoint)
             
             if details and isinstance(details, list) and len(details) > 0:
                 stage_attempt = details[0]
@@ -650,8 +715,8 @@ class APIClient:
         """Get all stages for a specific application."""
         logging.debug(f"Fetching all stages for application {app_id}")
         try:
-            clean_app_id = app_id.strip()
-            stages = self._make_request(f"/applications/{clean_app_id}/stages")
+            endpoint = self._build_app_endpoint(app_id, "/stages")
+            stages = self._make_request(endpoint)
             logging.debug(f"Found {len(stages)} stages for application {app_id}")
             return stages
         except Exception as e:
