@@ -21,7 +21,7 @@ class S3Uploader:
     DEFAULT_API_KEY = "prR1Lzi+xM+bcSp+6hyqHg=="
     DEFAULT_API_SECRET = "9Z+SbOvQbgoQCqFwkh97unrCTcGdpPBZhmEV5MD0yr8="
     DEFAULT_ORG_ID = "aa6e0325-1987-4295-a140-02bf22adce1e"
-    DEFAULT_USER_ID = "nQOT2J5l38hTH7VHesBrkQAm1ZF2"
+    DEFAULT_USER_ID = "As1xjFqiiDUKdtrCnMk8Yp4PhzQ2"
     
     MAX_RETRIES = 3
     RETRY_DELAY_MS = 1000
